pub enum PendingCallerTrack {
StartedForEarlyMedia,
NotStarted(Box<dyn Track>),
}Expand description
Describes the state of the caller track when an incoming SIP call is waiting to be answered.
Variants
StartedForEarlyMedia
The track has been started in the media stream during ringing (early media). Processors must be built from the accept option and appended to it.
NotStarted(Box<dyn Track>)
The track has not been added to the media stream yet. setup_track_with_stream will start it and build processors from the accept option.