pub struct TrunkRule {
pub rule: TrunkRuleDef,
}Expand description
Trunk-like SIP INVITE/REFER rewriting rule.
Rules are evaluated in declaration order and the first rule whose match
conditions all hold (AND) is applied via its rewrite actions
(first-match-wins). A rule with an empty match section always matches and
therefore acts as a catch-all default.
[[trunk_rules]]
rule.match.to.host = "^172\\.25\\."
rule.rewrite.contact.host = "172.25.225.2"Fields
rule: TrunkRuleDefTrait Implementations
Sourceimpl<'de> Deserialize<'de> for TrunkRule
impl<'de> Deserialize<'de> for TrunkRule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for TrunkRule