pub async fn tunnel(
client: WebSocket,
peer: WebSocketStream<MaybeTlsStream<TcpStream>>,
)Expand description
Bidirectionally relay frames between the client websocket and the peer websocket until either side closes.
pub async fn tunnel(
client: WebSocket,
peer: WebSocketStream<MaybeTlsStream<TcpStream>>,
)Bidirectionally relay frames between the client websocket and the peer websocket until either side closes.