pub struct TrackCodec {
pub payload_type_map: Arc<RwLock<HashMap<u8, CodecType>>>,
/* private fields */
}Fields
payload_type_map: Arc<RwLock<HashMap<u8, CodecType>>>Implementations
Sourceimpl TrackCodec
impl TrackCodec
pub fn new() -> Self
pub fn set_payload_type(&mut self, pt: u8, codec: CodecType)
Sourcepub fn get_codec_for_pt(&self, pt: u8) -> Option<CodecType>
pub fn get_codec_for_pt(&self, pt: u8) -> Option<CodecType>
Look up the codec for a given RTP payload type, consulting the negotiated map first and falling back to the static payload type registry.
pub fn is_audio(payload_type: u8) -> bool
pub fn decode( &mut self, payload_type: u8, payload: &[u8], target_sample_rate: u32, ) -> (u32, u16, PcmBuf)
pub fn resample(&mut self, pcm: PcmBuf, in_rate: u32, out_rate: u32) -> PcmBuf
pub fn encode(&mut self, payload_type: u8, frame: AudioFrame) -> (u8, Vec<u8>)