Module playbook

Module playbook 

Re-exports

pub use dialogue::DialogueHandler;
pub use handler::LlmHandler;
pub use handler::RagRetriever;
pub use runner::PlaybookRunner;

Modules

dialogue
handler
runner

Structs

ChatMessage
DtmfCollectorConfig
Configuration for a DTMF digit collector template
DtmfValidation
Validation rule for DTMF digit collection
FollowUpConfig
InterruptionConfig
LlmConfig
Playbook
PlaybookConfig
PostHookConfig
Scene

Enums

DtmfAction
InterruptionStrategy
SummaryType

Constants

BUILTIN_CALLEE
BUILTIN_CALLER
BUILTIN_CALL_TYPE
BUILTIN_SESSION_ID
Built-in session variable key constants. These are automatically injected into extras so they can be referenced in playbook templates using {{ session_id }}, {{ call_type }}, etc.
BUILTIN_START_TIME

Functions

render_scene_prompt
Render a scene prompt template dynamically using the current variables. This allows set_var values set during conversation to be used in scene prompts.