pub enum Command {
Show 14 variants
Invite {
option: CallOption,
},
Accept {
option: CallOption,
},
Reject {
reason: String,
code: Option<u32>,
},
Ringing {
recorder: Option<RecorderOption>,
early_media: Option<bool>,
ringtone: Option<String>,
},
Tts {
text: String,
speaker: Option<String>,
play_id: Option<String>,
auto_hangup: Option<bool>,
streaming: Option<bool>,
end_of_stream: Option<bool>,
option: Option<SynthesisOption>,
wait_input_timeout: Option<u32>,
base64: Option<bool>,
cache_key: Option<String>,
},
Play {
url: String,
play_id: Option<String>,
auto_hangup: Option<bool>,
wait_input_timeout: Option<u32>,
},
Interrupt {
graceful: Option<bool>,
fade_out_ms: Option<u32>,
},
Pause {},
Resume {},
Hangup {
reason: Option<String>,
initiator: Option<String>,
headers: Option<HashMap<String, String>>,
},
Refer {
caller: String,
callee: String,
options: Option<ReferOption>,
},
Mute {
track_id: Option<String>,
},
Unmute {
track_id: Option<String>,
},
History {
speaker: String,
text: String,
},
}Variants
Invite
Fields

option: CallOptionAccept
Fields

option: CallOptionReject
Ringing
Tts
Fields

auto_hangup: Option<bool>If auto_hangup is true, it means the call will be hung up automatically after the TTS playback is finished

streaming: Option<bool>If streaming is true, it means the input text is streaming text, and end_of_stream needs to be used to determine if it’s finished, equivalent to LLM’s streaming output to TTS synthesis

option: Option<SynthesisOption>Play
Fields
Interrupt
Pause
Resume
Hangup
Refer
Fields

options: Option<ReferOption>Mute
Unmute
History