Re-exports
pub use dialogue::DialogueHandler;pub use handler::LlmHandler;pub use handler::RagRetriever;pub use runner::PlaybookRunner;
Modules
Structs
- Chat
Message - Dtmf
Collector Config - Configuration for a DTMF digit collector template
- Dtmf
Validation - Validation rule for DTMF digit collection
- Follow
UpConfig - Interruption
Config - LlmConfig
- Playbook
- Playbook
Config - Post
Hook Config - Scene
Enums
Constants
- BUILTIN_
CALLEE - BUILTIN_
CALLER - BUILTIN_
CALL_ TYPE - BUILTIN_
SESSION_ ID - Built-in session variable key constants.
These are automatically injected into
extrasso they can be referenced in playbook templates using{{ session_id }},{{ call_type }}, etc. - BUILTIN_
START_ TIME
Functions
- render_
scene_ prompt - Render a scene prompt template dynamically using the current variables.
This allows
set_varvalues set during conversation to be used in scene prompts.